@@ -16,14 +16,13 @@
  * limitations under the License.
  */
 
-
 // open fd/3 as that's where we send the result
-$fd3 = fopen('php://fd/3', 'w');
+$fd3 = fopen('php://fd/3', 'wb');
 
 // Register a shutdown function so that we can fail gracefully when a fatal error occurs
-register_shutdown_function(function () use ($fd3) {
+register_shutdown_function(static function () use ($fd3) {
     $error = error_get_last();
-    if ($error && in_array($error['type'], [E_ERROR, E_CORE_ERROR, E_COMPILE_ERROR, E_USER_ERROR])) {
+    if ($error && in_array($error['type'], [E_ERROR, E_CORE_ERROR, E_COMPILE_ERROR, E_USER_ERROR], true)) {
         file_put_contents('php://stderr', "An error occurred running the action.\n");
         fwrite($fd3, "An error occurred running the action.\n");
     }
@@ -72,8 +71,8 @@ while ($f = fgets(STDIN)) {
         // process the result
         if (!is_array($result)) {
             file_put_contents('php://stderr', 'Result must be an array but has type "'
-                . gettype($result) . '": ' . (string)$result);
-            file_put_contents('php://stdout', 'The action did not return a dictionary.');
+                . gettype($result) . '": ' . $result);
+            file_put_contents('php://stdout', 'The action did not return a dictionary or array.');
             $result = (string)$result;
         } else {
             $result = json_encode((object)$result);
